@@ -19,7 +19,7 @@ class Recipe:
         
         version = self.options.get('version')
         if version is None:
-            version = '1.21'
+            version = '1.22'
         else:
             version = version.strip()
         if not os.path.isdir(download_dir):
@@ -44,7 +44,7 @@ class Recipe:
         setuptools.archive_util.unpack_archive(fname, target)
         result = os.path.join(target, 'MaildropHost')
         
-        # configure config.py
+        # configure config.py or config
         # Format of options is 
         #     key : type
         # Type may be string or number
@@ -83,12 +83,17 @@ class Recipe:
                     raise Exception, 'Unknown variable type'
         
         # read old configuration
-        config = open(os.path.join(result, 'config.py'), 'rU')
+        # 'config' is used in MDH 1.22+
+        # 'config.py' in MDH up to 1.21
+        config_name = os.path.join(result, 'config.py')
+        if not os.path.isfile(config_name):
+            config_name = os.path.join(result, 'config')
+        config = open(config_name, 'rU')
         old_config = config.readlines()
         config.close()
         
         # write new configuration
-        config = open(os.path.join(result, 'config.py'), 'w')
+        config = open(config_name, 'w')
         for line in old_config:
             processed = False
             for k,v in values.items():
